@@ -2,7 +2,7 @@
 static const char xml_feature_btrace_dtd[] = {
   '<', '!', '-', '-', ' ', 'C', 'o', 'p', 'y', 'r', 
    'i', 'g', 'h', 't', ' ', '(', 'C', ')', ' ', '2', 
-   '0', '1', '3', '-', '2', '0', '2', '1', ' ', 'F', 
+   '0', '1', '3', '-', '2', '0', '2', '4', ' ', 'F', 
    'r', 'e', 'e', ' ', 'S', 'o', 'f', 't', 'w', 'a', 
    'r', 'e', ' ', 'F', 'o', 'u', 'n', 'd', 'a', 't', 
    'i', 'o', 'n', ',', ' ', 'I', 'n', 'c', '.', '\n', 
@@ -89,7 +89,7 @@ static const char xml_feature_btrace_dtd[] = {
 static const char xml_feature_btrace_conf_dtd[] = {
   '<', '!', '-', '-', ' ', 'C', 'o', 'p', 'y', 'r', 
    'i', 'g', 'h', 't', ' ', '(', 'C', ')', ' ', '2', 
-   '0', '1', '3', '-', '2', '0', '2', '1', ' ', 'F', 
+   '0', '1', '3', '-', '2', '0', '2', '4', ' ', 'F', 
    'r', 'e', 'e', ' ', 'S', 'o', 'f', 't', 'w', 'a', 
    'r', 'e', ' ', 'F', 'o', 'u', 'n', 'd', 'a', 't', 
    'i', 'o', 'n', ',', ' ', 'I', 'n', 'c', '.', '\n', 
@@ -140,11 +140,21 @@ static const char xml_feature_btrace_conf_dtd[] = {
    'p', 't', '\011', 's', 'i', 'z', 'e', '\011', 'C', 'D', 
    'A', 'T', 'A', '\011', '#', 'I', 'M', 'P', 'L', 'I', 
    'E', 'D', '>', '\n', 
+  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
+   'p', 't', '\011', 'p', 't', 'w', 'r', 'i', 't', 'e', 
+   '\011', '(', 'y', 'e', 's', ' ', '|', ' ', 'n', 'o', 
+   ')', ' ', '#', 'I', 'M', 'P', 'L', 'I', 'E', 'D', 
+   '>', '\n', 
+  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
+   'p', 't', '\011', 'e', 'v', 'e', 'n', 't', '-', 't', 
+   'r', 'a', 'c', 'i', 'n', 'g', '\011', '(', 'y', 'e', 
+   's', ' ', '|', ' ', 'n', 'o', ')', '\011', '#', 'I', 
+   'M', 'P', 'L', 'I', 'E', 'D', '>', '\n', 
   0 };
 static const char xml_feature_gdb_target_dtd[] = {
   '<', '!', '-', '-', ' ', 'C', 'o', 'p', 'y', 'r', 
    'i', 'g', 'h', 't', ' ', '(', 'C', ')', ' ', '2', 
-   '0', '0', '7', '-', '2', '0', '2', '1', ' ', 'F', 
+   '0', '0', '7', '-', '2', '0', '2', '4', ' ', 'F', 
    'r', 'e', 'e', ' ', 'S', 'o', 'f', 't', 'w', 'a', 
    'r', 'e', ' ', 'F', 'o', 'u', 'n', 'd', 'a', 't', 
    'i', 'o', 'n', ',', ' ', 'I', 'n', 'c', '.', '\n', 
@@ -363,7 +373,7 @@ static const char xml_feature_gdb_target_dtd[] = {
 static const char xml_feature_library_list_dtd[] = {
   '<', '!', '-', '-', ' ', 'C', 'o', 'p', 'y', 'r', 
    'i', 'g', 'h', 't', ' ', '(', 'C', ')', ' ', '2', 
-   '0', '0', '7', '-', '2', '0', '2', '1', ' ', 'F', 
+   '0', '0', '7', '-', '2', '0', '2', '4', ' ', 'F', 
    'r', 'e', 'e', ' ', 'S', 'o', 'f', 't', 'w', 'a', 
    'r', 'e', ' ', 'F', 'o', 'u', 'n', 'd', 'a', 't', 
    'i', 'o', 'n', ',', ' ', 'I', 'n', 'c', '.', '\n', 
@@ -444,7 +454,7 @@ static const char xml_feature_library_list_dtd[] = {
 static const char xml_feature_library_list_aix_dtd[] = {
   '<', '!', '-', '-', ' ', 'C', 'o', 'p', 'y', 'r', 
    'i', 'g', 'h', 't', ' ', '(', 'C', ')', ' ', '2', 
-   '0', '1', '3', '-', '2', '0', '2', '1', ' ', 'F', 
+   '0', '1', '3', '-', '2', '0', '2', '4', ' ', 'F', 
    'r', 'e', 'e', ' ', 'S', 'o', 'f', 't', 'w', 'a', 
    'r', 'e', ' ', 'F', 'o', 'u', 'n', 'd', 'a', 't', 
    'i', 'o', 'n', ',', ' ', 'I', 'n', 'c', '.', '\n', 
@@ -531,7 +541,7 @@ static const char xml_feature_library_list_aix_dtd[] = {
 static const char xml_feature_library_list_svr4_dtd[] = {
   '<', '!', '-', '-', ' ', 'C', 'o', 'p', 'y', 'r', 
    'i', 'g', 'h', 't', ' ', '(', 'C', ')', ' ', '2', 
-   '0', '1', '1', '-', '2', '0', '2', '1', ' ', 'F', 
+   '0', '1', '1', '-', '2', '0', '2', '4', ' ', 'F', 
    'r', 'e', 'e', ' ', 'S', 'o', 'f', 't', 'w', 'a', 
    'r', 'e', ' ', 'F', 'o', 'u', 'n', 'd', 'a', 't', 
    'i', 'o', 'n', ',', ' ', 'I', 'n', 'c', '.', '\n', 
@@ -610,11 +620,38 @@ static const char xml_feature_library_list_svr4_dtd[] = {
    '_', 'l', 'd', ' ', ' ', ' ', ' ', 'C', 'D', 'A', 
    'T', 'A', ' ', ' ', ' ', '#', 'R', 'E', 'Q', 'U', 
    'I', 'R', 'E', 'D', '>', '\n', 
+  '<', '!', '-', '-', ' ', 'a', 'd', 'd', 'e', 'd', 
+   ' ', 'l', 'm', 'i', 'd', ' ', 'a', 't', 't', 'r', 
+   'i', 'b', 'u', 't', 'e', ' ', 't', 'o', ' ', 'w', 
+   'h', 'a', 't', ' ', 's', 'h', 'o', 'u', 'l', 'd', 
+   ' ', 'h', 'a', 'v', 'e', ' ', 'b', 'e', 'c', 'o', 
+   'm', 'e', ' ', 'v', 'e', 'r', 's', 'i', 'o', 'n', 
+   ' ', '1', '.', '1', ' ', 'b', 'u', 't', '\n', 
+  ' ', ' ', ' ', ' ', ' ', 's', 'i', 'n', 'c', 'e', 
+   ' ', 't', 'h', 'i', 's', ' ', 'g', 'e', 'n', 'e', 
+   'r', 'a', 't', 'e', 's', ' ', 'a', ' ', 'w', 'a', 
+   'r', 'n', 'i', 'n', 'g', ' ', 'i', 'n', ' ', 'G', 
+   'D', 'B', ' ', 'a', 'n', 'd', ' ', 's', 'i', 'n', 
+   'c', 'e', ' ', 'u', 'n', 'k', 'n', 'o', 'w', 'n', 
+   ' ', 'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 
+   's', '\n', 
+  ' ', ' ', ' ', ' ', ' ', 'a', 'r', 'e', ' ', 'i', 
+   'g', 'n', 'o', 'r', 'e', 'd', ',', ' ', 'a', 'n', 
+   'y', 'w', 'a', 'y', ',', ' ', 'l', 'e', 'a', 'v', 
+   'i', 'n', 'g', ' ', 't', 'h', 'e', ' ', 'v', 'e', 
+   'r', 's', 'i', 'o', 'n', ' ', 'a', 't', ' ', '1', 
+   '.', '0', '.', ' ', '-', '-', '>', '\n', 
+  '<', '!', 'A', 'T', 'T', 'L', 'I', 'S', 'T', ' ', 
+   'l', 'i', 'b', 'r', 'a', 'r', 'y', ' ', ' ', ' ', 
+   ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', 'l', 
+   'm', 'i', 'd', ' ', ' ', ' ', ' ', 'C', 'D', 'A', 
+   'T', 'A', ' ', ' ', ' ', '#', 'I', 'M', 'P', 'L', 
+   'I', 'E', 'D', '>', '\n', 
   0 };
 static const char xml_feature_osdata_dtd[] = {
   '<', '!', '-', '-', ' ', 'C', 'o', 'p', 'y', 'r', 
    'i', 'g', 'h', 't', ' ', '(', 'C', ')', ' ', '2', 
-   '0', '0', '8', '-', '2', '0', '2', '1', ' ', 'F', 
+   '0', '0', '8', '-', '2', '0', '2', '4', ' ', 'F', 
    'r', 'e', 'e', ' ', 'S', 'o', 'f', 't', 'w', 'a', 
    'r', 'e', ' ', 'F', 'o', 'u', 'n', 'd', 'a', 't', 
    'i', 'o', 'n', ',', ' ', 'I', 'n', 'c', '.', '\n', 
@@ -675,7 +712,7 @@ static const char xml_feature_osdata_dtd[] = {
 static const char xml_feature_threads_dtd[] = {
   '<', '!', '-', '-', ' ', 'C', 'o', 'p', 'y', 'r', 
    'i', 'g', 'h', 't', ' ', '(', 'C', ')', ' ', '2', 
-   '0', '0', '8', '-', '2', '0', '2', '1', ' ', 'F', 
+   '0', '0', '8', '-', '2', '0', '2', '4', ' ', 'F', 
    'r', 'e', 'e', ' ', 'S', 'o', 'f', 't', 'w', 'a', 
    'r', 'e', ' ', 'F', 'o', 'u', 'n', 'd', 'a', 't', 
    'i', 'o', 'n', ',', ' ', 'I', 'n', 'c', '.', '\n', 
@@ -727,7 +764,7 @@ static const char xml_feature_threads_dtd[] = {
 static const char xml_feature_traceframe_info_dtd[] = {
   '<', '!', '-', '-', ' ', 'C', 'o', 'p', 'y', 'r', 
    'i', 'g', 'h', 't', ' ', '(', 'C', ')', ' ', '2', 
-   '0', '1', '0', '-', '2', '0', '2', '1', ' ', 'F', 
+   '0', '1', '0', '-', '2', '0', '2', '4', ' ', 'F', 
    'r', 'e', 'e', ' ', 'S', 'o', 'f', 't', 'w', 'a', 
    'r', 'e', ' ', 'F', 'o', 'u', 'n', 'd', 'a', 't', 
    'i', 'o', 'n', ',', ' ', 'I', 'n', 'c', '.', '\n', 
@@ -801,7 +838,7 @@ static const char xml_feature_traceframe_info_dtd[] = {
 static const char xml_feature_xinclude_dtd[] = {
   '<', '!', '-', '-', ' ', 'C', 'o', 'p', 'y', 'r', 
    'i', 'g', 'h', 't', ' ', '(', 'C', ')', ' ', '2', 
-   '0', '0', '7', '-', '2', '0', '2', '1', ' ', 'F', 
+   '0', '0', '7', '-', '2', '0', '2', '4', ' ', 'F', 
    'r', 'e', 'e', ' ', 'S', 'o', 'f', 't', 'w', 'a', 
    'r', 'e', ' ', 'F', 'o', 'u', 'n', 'd', 'a', 't', 
    'i', 'o', 'n', ',', ' ', 'I', 'n', 'c', '.', '\n', 
